@@ -6,17 +6,17 @@
  * Author: Federico Mena-Quintero <federico@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_COMPONENT_H
@@ -38,6 +38,11 @@ G_BEGIN_DECLS
 #define E_IS_CAL_COMPONENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_CAL_COMPONENT))
 #define E_IS_CAL_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), E_TYPE_CAL_COMPONENT))
 
+typedef struct {
+	char *uid;
+	char *rid;
+} ECalComponentId;
+
 /* Types of calendar components to be stored by a ECalComponent, as per RFC 2445.
  * We don't put the alarm component type here since we store alarms as separate
  * structures inside the other "real" components.
@@ -129,7 +134,7 @@ typedef enum {
 
 typedef struct {
 	ECalComponentRangeType type;
-	
+
 	ECalComponentDateTime datetime;
 } ECalComponentRange;
 
@@ -150,23 +155,23 @@ typedef enum {
 	E_CAL_COMPONENT_TRANSP_UNKNOWN
 } ECalComponentTransparency;
 
-/* Organizer & Attendee */	
+/* Organizer & Attendee */
 typedef struct {
 	const char *value;
-	
+
 	const char *member;
 	icalparameter_cutype cutype;
 	icalparameter_role role;
 	icalparameter_partstat status;
 	gboolean rsvp;
-	
+
 	const char *delto;
 	const char *delfrom;
 	const char *sentby;
 	const char *cn;
 	const char *language;
 } ECalComponentAttendee;
-	
+
 typedef struct {
 	const char *value;
 	const char *sentby;
@@ -221,6 +226,9 @@ void e_cal_component_abort_sequence (ECalComponent *comp);
 void e_cal_component_get_uid (ECalComponent *comp, const char **uid);
 void e_cal_component_set_uid (ECalComponent *comp, const char *uid);
 
+ECalComponentId *e_cal_component_get_id (ECalComponent *comp);
+void e_cal_component_free_id (ECalComponentId *id);
+
 void e_cal_component_get_categories (ECalComponent *comp, const char **categories);
 void e_cal_component_set_categories (ECalComponent *comp, const char *categories);
 void e_cal_component_get_categories_list (ECalComponent *comp, GSList **categ_list);
@@ -322,6 +330,13 @@ gboolean e_cal_component_has_attendees (ECalComponent *comp);
 void e_cal_component_get_location (ECalComponent *comp, const char **location);
 void e_cal_component_set_location (ECalComponent *comp, const char *location);
 
+/* Attachment handling */
+void e_cal_component_get_attachment_list (ECalComponent *comp, GSList **attachment_list);
+void e_cal_component_set_attachment_list (ECalComponent *comp, GSList *attachment_list);
+gboolean e_cal_component_has_attachments (ECalComponent *comp);
+int e_cal_component_get_num_attachments (ECalComponent *comp);
+
+
 gboolean e_cal_component_event_dates_match (ECalComponent *comp1, ECalComponent *comp2);
 
 
