@@ -5,7 +5,7 @@
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,32 +13,32 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <unistd.h>
 #include <ctype.h>
-#include <string.h>
 #include <errno.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 
-#include "camel-imap-store-summary.h"
+#include <libedataserver/md5-utils.h>
+#include <libedataserver/e-memory.h>
 
 #include "camel-file-utils.h"
-
-#include "libedataserver/md5-utils.h"
-#include "libedataserver/e-memory.h"
-
 #include "camel-private.h"
+#include "camel-store.h"
 #include "camel-utf8.h"
 
+#include "camel-imap-store-summary.h"
+
 #define d(x)
 #define io(x)			/* io debug */
 
@@ -48,6 +48,8 @@
 
 #define _PRIVATE(o) (((CamelImapStoreSummary *)(o))->priv)
 
+static void namespace_clear(CamelStoreSummary *s);
+
 static int summary_header_load(CamelStoreSummary *, FILE *);
 static int summary_header_save(CamelStoreSummary *, FILE *);
 
@@ -107,7 +109,7 @@ CamelType
 camel_imap_store_summary_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		camel_imap_store_summary_parent = (CamelStoreSummaryClass *)camel_store_summary_get_type();
 		type = camel_type_register((CamelType)camel_imap_store_summary_parent, "CamelImapStoreSummary",
@@ -118,7 +120,7 @@ camel_imap_store_summary_get_type (void)
 					   (CamelObjectInitFunc) camel_imap_store_summary_init,
 					   (CamelObjectFinalizeFunc) camel_imap_store_summary_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -126,7 +128,7 @@ camel_imap_store_summary_get_type (void)
  * camel_imap_store_summary_new:
  *
  * Create a new CamelImapStoreSummary object.
- * 
+ *
  * Return value: A new CamelImapStoreSummary widget.
  **/
 CamelImapStoreSummary *
@@ -139,14 +141,14 @@ camel_imap_store_summary_new (void)
 
 /**
  * camel_imap_store_summary_full_name:
- * @s: 
- * @path: 
- * 
+ * @s:
+ * @path:
+ *
  * Retrieve a summary item by full name.
  *
  * A referenced to the summary item is returned, which may be
  * ref'd or free'd as appropriate.
- * 
+ *
  * Return value: The summary item, or NULL if the @full_name name
  * is not available.
  * It must be freed using camel_store_summary_info_free().
@@ -192,7 +194,7 @@ camel_imap_store_summary_full_to_path(CamelImapStoreSummary *s, const char *full
 	} else
 		path = (char *)full_name;
 
-	return camel_utf7_utf8(path);
+	return g_strdup(path);
 }
 
 static guint32 hexnib(guint32 c)
@@ -208,7 +210,7 @@ static guint32 hexnib(guint32 c)
 char *
 camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path, char dir_sep)
 {
-	unsigned char *full, *f;
+	char *full, *f;
 	guint32 c, v = 0;
 	const char *p;
 	int state=0;
@@ -245,7 +247,7 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 	else
 		p = path;
 
-	while ( (c = camel_utf8_getc((const unsigned char **)&p)) ) {
+	while ((c = camel_utf8_getc((const unsigned char **)&p))) {
 		switch(state) {
 		case 0:
 			if (c == '%')
@@ -253,7 +255,7 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 			else {
 				if (c == '/')
 					c = dir_sep;
-				camel_utf8_putc(&f, c);
+				camel_utf8_putc((unsigned char **) &f, c);
 			}
 			break;
 		case 1:
@@ -263,14 +265,14 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 		case 2:
 			state = 0;
 			v |= hexnib(c);
-			camel_utf8_putc(&f, v);
+			camel_utf8_putc((unsigned char **) &f, v);
 			break;
 		}
 	}
-	camel_utf8_putc(&f, c);
+	camel_utf8_putc((unsigned char **) &f, c);
 
 	/* merge old path part if required */
-	f = camel_utf8_utf7(full);
+	f = g_strdup(full);
 	if (si) {
 		full = g_strdup_printf("%s%s", camel_imap_store_info_full_name(s, si), f);
 		g_free(f);
@@ -318,7 +320,7 @@ camel_imap_store_summary_add_from_full(CamelImapStoreSummary *s, const char *ful
 		} else {
 			if (full_name[len] == ns->sep)
 				len++;
-			
+
 			prefix = camel_imap_store_summary_full_to_path(s, full_name+len, ns->sep);
 			if (*ns->path) {
 				pathu8 = g_strdup_printf ("%s/%s", ns->path, prefix);
@@ -337,6 +339,9 @@ camel_imap_store_summary_add_from_full(CamelImapStoreSummary *s, const char *ful
 	if (info) {
 		d(printf("  '%s' -> '%s'\n", pathu8, full_name));
 		camel_store_info_set_string((CamelStoreSummary *)s, (CamelStoreInfo *)info, CAMEL_IMAP_STORE_INFO_FULL_NAME, full_name);
+
+		if (g_ascii_strcasecmp(full_name, "inbox"))
+			info->info.flags |= CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_TYPE_INBOX;
 	} else
 		d(printf("  failed\n"));
 
@@ -389,8 +394,6 @@ CamelImapStoreNamespace *camel_imap_store_summary_namespace_new(CamelImapStoreSu
 
 void camel_imap_store_summary_namespace_set(CamelImapStoreSummary *s, CamelImapStoreNamespace *ns)
 {
-	static void namespace_clear(CamelStoreSummary *s);
-
 	d(printf("Setting namesapce to '%s' '%c' -> '%s'\n", ns->full_name, ns->sep, ns->path));
 	namespace_clear((CamelStoreSummary *)s);
 	s->namespace = ns;
@@ -534,7 +537,7 @@ summary_header_save(CamelStoreSummary *s, FILE *out)
 	if (camel_imap_store_summary_parent->summary_header_save((CamelStoreSummary *)s, out) == -1
 	    || camel_file_util_encode_fixed_int32(out, CAMEL_IMAP_STORE_SUMMARY_VERSION) == -1
 	    || camel_file_util_encode_fixed_int32(out, is->capabilities) == -1
-	    || camel_file_util_encode_fixed_int32(out, count) == -1)	    
+	    || camel_file_util_encode_fixed_int32(out, count) == -1)
 		return -1;
 
 	if (is->namespace && namespace_save(s, out, is->namespace) == -1)
@@ -553,6 +556,10 @@ store_info_load(CamelStoreSummary *s, FILE *in)
 		if (camel_file_util_decode_string(in, &mi->full_name) == -1) {
 			camel_store_summary_info_free(s, (CamelStoreInfo *)mi);
 			mi = NULL;
+		} else {
+			/* NB: this is done again for compatability */
+			if (g_ascii_strcasecmp(mi->full_name, "inbox") == 0)
+				mi->info.flags |= CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_TYPE_INBOX;
 		}
 	}
 
